@@ -13,9 +13,10 @@ def test_func():
     return math.inf
 
 class GT:
-    def __init__(self, DM_req, size_of_clusters):
+    def __init__(self, DM_req, size_of_clusters, number_of_depots):
         self.DM_req = DM_req
         self.size_of_clusters = size_of_clusters
+        self.number_of_depots = number_of_depots
 
     def total_clustering(self, DM_req, size_of_clusters):
         # DM_req, number_of_clusters, small_cluster_num
@@ -300,7 +301,7 @@ class GT:
                 giant_tour.append(trip[0])
         return giant_tour
 
-    def draw_cluster_result(self, cluster_result, center_point=[], GT_between_cluster=[], in_out_original=[],
+    def draw_cluster_result(self, number_of_depots, cluster_result, center_point=[], GT_between_cluster=[], in_out_original=[],
                             giant_tour=[]):
 
         from matplotlib.pyplot import figure
@@ -346,7 +347,7 @@ class GT:
             Y.append(location[p][1])
         plt.plot(X, Y, 'r', alpha=1)
 
-    def create_draw_giant_tour(self):
+    def create_draw_giant_tour(self, number_of_depots):
         DM_req = self.DM_req
         size_of_clusters = self.size_of_clusters
         cluster_result = self.total_clustering(DM_req, size_of_clusters)
